import { Intent } from '@blueprintjs/core';
import * as React from 'react';
declare class Confirm {
    private _container;
    private constructor();
    private static _SingleInstance;
    static GetInstance(): Confirm;
    close(): void;
    show(option: {
        message: string | string[];
        hasCancel?: boolean;
        confirmButtonText?: string;
        cancelButtonText?: string;
        intent?: Intent;
        ignore?: boolean;
    }): Promise<boolean>;
    show2(option: {
        message: string | string[];
        onConfirm: () => void;
        onCanel?: () => void;
    }): void;
    /**
     * 多按钮确认框
     * @example
     * // res=0关闭 res=1确定 res=2取消 res=3帮助
     * const res = await AppConfirm.show3({
     *     message: "你确定要删除吗？",
     *     buttons: [
     *         { text: "确定", type: Intent.SUCCESS, status: 1 },
     *         { text: "取消", type: Intent.DANGER, status: 2 },
     *         { text: "帮助", type: Intent.WARNING, status: 3 },
     *     ]
     * })
     */
    show3(option: {
        message: string | string[];
        buttons?: {
            text: string;
            type: Intent;
            status: number;
        }[];
    }): Promise<number>;
}
interface ICommonConfirmProps {
    message: string | string[];
    res: Function;
    close: Function;
    hasCancel: boolean;
    confirmButtonText?: string;
    cancelButtonText?: string;
    intent?: Intent;
    ignore?: boolean;
}
/**
 * 类似原生api confirm
 * 呼出界面时,我们捕获了所有键盘事件,避免触发组合键.
 * 并且我们不运行键盘直接确认,必须点击确认(防止操作过快)
 * esc取消
 */
export declare class CommonConfirm extends React.Component<ICommonConfirmProps> {
    renderMessage: () => string | JSX.Element[];
    componentDidMount(): void;
    componentWillUnmount(): void;
    render(): JSX.Element;
    private confirm;
    private cancel;
    private keydown;
    private keyup;
}
export declare const AppConfirm: Confirm;
export {};
//# sourceMappingURL=Confirm.d.ts.map