import React from "react";
import "./PulldownSelect.css";
type optionType = {
    value: string;
    label: string;
};
type SelectProps = {
    children?: React.ReactNode;
    value?: string;
    options?: optionType[];
    readOnly?: boolean;
    canInput?: boolean;
    defaultShow?: boolean;
    onChange?: (option: optionType) => void;
    onInput?: (value: string) => void;
    onBlur?: (e: React.FormEvent<HTMLDivElement>) => void;
};
/**
 * 下拉选择器
 * @param {string} [value] 当前选择的值
 * @param {{value: string; label: string;}[]} [options] 选项列表
 * @param {boolean} [readOnly] 是否只读，默认false
 * @param {boolean} [canInput] 是否支持输入，默认false
 * @param {boolean} [defaultShow] 是否默认显示下拉选项，默认false
 * @param {Function} [onChange] 选项变化的回调函数
 * @param {Function} [onInput] 内容输入的回调函数
 * @param {Function} [onBlur] 失去焦点的回调函数
 * @example
   const [val, setVal] = React.useState("A");
   const options = [{ value: "A", label: "选项A" }, { value: "B", label: "选项B" }];
   const handleChange = (o: any) => {setVal(o.value)};
   <PulldownSelect value={val} options={options} onChange={handleChange} />
 */
export declare function PulldownSelect(props: SelectProps): JSX.Element;
export {};
//# sourceMappingURL=PulldownSelect.d.ts.map