import { CellBase, Matrix } from "react-spreadsheet";
import "./TableSheet.css";
type MultiCellValue = {
    type?: "text" | "select";
    options?: {
        value: string;
        label: string;
    }[];
};
export type ProCellBase<T> = {
    multiValue?: MultiCellValue;
} & CellBase<T>;
/** 单元格里的值的类型 */
export type CellValue = string;
/** TableSheet组件的props类型 */
type TableSheetProps = {
    className?: string;
    /** 数据 */
    data: Matrix<ProCellBase<CellValue>>;
    /** 列标签 */
    columnLabels?: string[];
    /** 行标签 */
    rowLabels?: string[];
    /** 表头是否可拖动调节列宽 */
    resizable?: boolean;
    /** 数据变化的回调 */
    onChange?: (data: Matrix<ProCellBase<CellValue>>) => void;
};
/**
 * 类Excel的表格组件
 * @param {Matrix<CellBase<CellValue>>} data 数据
 * @param {string[]} [columnLabels] 列标签
 * @param {string[]} [rowLabels] 行标签
 * @param {(data: Matrix<CellBase<CellValue>>) => void} [onChange] 数据变化的回调
 * @example
 * const columnLabels = ["第A列", "第B列"];
 * const rowLabels = ["第1行", "第2行"];
 * const data = [
    [{ value: "张三" }, { value: "刚满18岁(只读)", readOnly: true }],
    [{ value: "李四" }, { value: "80老头有低保", }],
  ];
 * const onChange = (data) => console.log(data);
 * <TableSheet data={data} columnLabels={columnLabels} rowLabels={rowLabels} onChange={onChange} />
 */
export declare function TableSheet(props: TableSheetProps): JSX.Element;
export {};
//# sourceMappingURL=TableSheet.d.ts.map